
// vincia21.cc is a part of the VINCIA event generator.
// Copyright (C) 2019 Peter Skands.
// VINCIA is licenced under the GNU GPL version 2, see COPYING for details.
// Please respect the MCnet Guidelines, see GUIDELINES for details.

// This is a simple test program (adapted from the PYTHIA example main05.cc)
// It studies gg->gg at the LHC, and is intended to test the interoperation
// of ISR and FSR in VINCIA.

// Pythia 40s
// Vincia 10s no FSR, no ISR, no QED
// Vincia 13s with FSR
// Vincia 280s with everything (still VERY slow but within factor 10)
// 

#include "Pythia8/Vincia.h"
using namespace Pythia8;

int main() {

  //************************************************************************
  // Generator. LHC process and output selection. Initialization.
  Pythia pythia;
  VinciaPlugin vincia(&pythia);

  // Read user settings from file
  pythia.readFile("vincia21.cmnd");

  //************************************************************************

  // Extract settings to be used in the main program.
  int nEvent = pythia.settings.mode("Main:numberOfEvents");
  int nAbort = pythia.settings.mode("Main:timesAllowErrors");
  bool vinciaOn = pythia.settings.flag("Vincia");
  
  //************************************************************************
  
  // Initialize
  if(!vincia.init()) { return EXIT_FAILURE; }
  
  //************************************************************************

  // Begin event loop. Generate event. Skip if error.
  int iAbort = 0;
  for (int iEvent = 0; iEvent < nEvent; ++iEvent) {
    
    bool aborted = !pythia.next();
    aborted = ( aborted || vincia.vinCom.doAbort()) ;
    
    if (aborted){
      if (++iAbort < nAbort){
	vincia.vinCom.setAbort(false);
	continue;
      }
      cout << " Event generation aborted prematurely, owing to error!\n";
      cout<< "Event number was : "<<iEvent<<endl;
      break;
    }

  // End of event loop. Statistics. Histograms.
  }
  pythia.stat();
  if (vinciaOn) vincia.printInfo();
  //cout << nJets << eTjets << etaJets << phiJets << distJets << eTdiff;

  // Done.
  return 0;
}
